@@ -4,11 +4,10 @@ use 5.006;
 use strict;
 use warnings FATAL => 'all';
 
-use Dancer2;
 use Dancer2::Plugin;
 use WWW::Sixpack;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 my $conf;
 
@@ -106,23 +105,23 @@ register experiment => sub {
 
     # user info
     my %options = ();
-       $options{ip_address} = $dsl->request->address
-           if $dsl->request->address;
-       $options{user_agent} = $dsl->request->agent
-           if $dsl->request->agent;
+       $options{ip_address} = $dsl->app->request->address
+           if $dsl->app->request->address;
+       $options{user_agent} = $dsl->app->request->agent
+           if $dsl->app->request->agent;
 
     # force if requested
-    $options{force} = $dsl->param("sixpack-force-$name")
-        if $dsl->param("sixpack-force-$name");
+    $options{force} = $dsl->app->request->param("sixpack-force-$name")
+        if $dsl->app->request->param("sixpack-force-$name");
 
     my $alt = $sixpack
         ->participate( $name, $alternatives, \%options );
 
-    my $experiments = $dsl->session('sixpack_experiments') || { };
+    my $experiments = $dsl->app->session->read('sixpack_experiments') || { };
        $experiments->{$name} = $alt->{alternative}{name};
 
-    $dsl->session->write('sixpack_id', $alt->{client_id});
-    $dsl->session->write('sixpack_experiments', $experiments);
+    $dsl->app->session->write('sixpack_id', $alt->{client_id});
+    $dsl->app->session->write('sixpack_experiments', $experiments);
 
     return $alt->{alternative}{name};
 };
@@ -153,7 +152,7 @@ register convert => sub {
         $return{$experiment} = $res->{status};
     } else {
         # no experiments given, look them up
-        my $experiments = $dsl->session('sixpack_experiments') || { };
+        my $experiments = $dsl->app->session->read('sixpack_experiments') || { };
         for my $exp (keys %{$experiments}) {
             my $res = $sixpack->convert($exp);
             $return{$exp} = $res->{status};
@@ -175,7 +174,7 @@ sub get_sixpack {
     $conf ||= plugin_setting();
 
     my %options;
-    my $client_id = $dsl->session('sixpack_id');
+    my $client_id = $dsl->app->session->read('sixpack_id');
 
     # need to pass info on to the sixpack object?
     $options{host}      = $conf->{host} if( defined $conf->{host} );
@@ -195,15 +194,14 @@ Please report any bugs or feature requests to C<bug-dancer2-plugin-sixpack at rt
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dancer2-Plugin-Sixpack>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-=head1 LICENSE AND COPYRIGHT
+=head1 COPYRIGHT
 
-Copyright 2013 Menno Blom.
+Copyright 2014- Menno Blom
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
+=head1 LICENSE
 
-See L<http://dev.perl.org/licenses/> for more information.
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
 
